/* SPDX-License-Identifier: GPL-3.0-or-later */
/* Copyright (C) 2021 KikooDX */

#include "conf.h"
#include "editing_area/draw.h"
#include "editing_area/level.h"
#include "shared_data.h"
#include <raylib.h>
#include <stdbool.h>
#include <stdlib.h>
#include <sys/wait.h>

int editing_area_main(int argc, char **argv,
                      struct SharedData *shared_data)
{
	struct Level level;
	level.data = NULL;

	/* initialize raylib */
	InitWindow(game_window_width, game_window_height,
	           "SLE main window");
	SetTargetFPS(editor_target_fps);
	/* load textures */
	const Texture2D tileset = LoadTexture(argv[1]);

	/* only proceed if tileset is well loaded */
	if (tileset.width > 0) {
		/* load level */
		level_read(&level, argv[2]);

		while (!WindowShouldClose()) {
			/* draw */
			BeginDrawing();

			ClearBackground(BLACK);
			level_draw(level, tileset);

			EndDrawing();
		}

		/* save level */
		level_write(level, argv[2]);
	}

	/* deinit */
	level_free(&level);

	/* unload textures */
	UnloadTexture(tileset);
	CloseWindow();

	/* tell to the child process it can end */
	shared_data->end_child = true;

	/* wait for child process to exit */
	wait(NULL);

	return EXIT_SUCCESS;
}
